@@ -1,5 +1,5 @@
-from src.sessionDef import serviceJoinInfo
-from src.srvCommon import queryConst, servMsgType
+from sessionDef import serviceJoinInfo
+from srvCommon import queryConst, servMsgType
 
 import json
 import base64
