@@ -1,5 +1,5 @@
 
-from src.srvCommon import servMsgType, wsMsgActionTypes
+from srvCommon import servMsgType, wsMsgActionTypes
 
 
 def pySourceInfoEncoder(pys):
